;***********************************************************************************************
;Programmname:			Projekt Ivy Mainboard Reset Circuit
;Funktion:				Auslsen eines Schaltungsreset oder Shutdown entsprechend den Eingangssignalen
;Prozessor:				Attiny25
;Systemtakt:			1MHz intern
;Version:				01.00
;Autor:					Florian Krause
;Datum:					2013-07-30
;Editor:				AVR Studio 6
;************************************************************************************************

.include		"tn25def.inc"												; Attiny25 Registerdefinitionen
.include		"UserCVarDefs.inc"											; User Definitions

;-Interrupt Vector Tabelle------------------------------------------------------------------------------------------
begin:			rjmp		main											; External Pin, Power-on, Brown-out and Watchdog Reset
				rjmp		noInt											; Externer Interrupt 0
				rjmp		noInt											; Pin Change Interrupt Request 0
				rjmp		noInt											; Timer/Counter1 Compare Match A
				rjmp		noInt											; Timer/Counter1 Overflow
				rjmp		noInt											; Timer/Counter0 Overflow
				rjmp		noInt											; Eeprom Ready
				rjmp		noInt											; Analog Comparator
				rjmp		noInt											; ADC Complete
				rjmp		noInt											; Timer/Counter1 Compare Match B
				rjmp		Sys_TC0_CpA_ISR									; Timer/Counter0 Compare Match A
				rjmp		noInt											; Timer/Counter0 Compare Match B
				rjmp		noInt											; Watchdog Timer Overflow
				rjmp		noInt											; USI Start Condition
				rjmp		noInt											; USI Overflow

noInt:			reti

;-Unterprogrammblcke-------------------------------------------------------------------------------------------------
.include		"Sys_Init.asm"
.include		"Ram_Init.asm"
.include		"Sys_ResetTimeCalc.asm"
.include		"Sys_TC0_CpA_ISR.asm"
.include		"Sys_ResetHandling.asm"

;-Initialisierung----------------------------------------------------------------------------------------------------
main:			ldi			r16,RAMEND										; initialisiere Stackpointer
				out			SPL,r16											; "

				rcall		Ram_Init										; Initialisierung der genutzten ramzellen

				rcall		Sys_Init										; Hauptinitialisierung

				rcall		Sys_ResetTimeCalc								; berechnung der resetzeit

				lds			r16,SRAM_CVAR_MAIN_STATEMEMORY					; lade statusbyte in r16
				ori			r16,0b00000001									; setze reset flag
				sts			SRAM_CVAR_MAIN_STATEMEMORY,r16					; speichere statusbyte

				sei															; global interrupt aktivieren

;-Hauptprogramm------------------------------------------------------------------------------------------------------
mainloop:		rjmp		mainloop

;---------------------------------------------------------------------------------------------------------------------